aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/core/file_sys/archive.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/core/file_sys/archive.h')
-rw-r--r--src/core/file_sys/archive.h17
1 files changed, 2 insertions, 15 deletions
diff --git a/src/core/file_sys/archive.h b/src/core/file_sys/archive.h
index 27ed23cd..b7978bfb 100644
--- a/src/core/file_sys/archive.h
+++ b/src/core/file_sys/archive.h
@@ -162,25 +162,12 @@ private:
class Archive : NonCopyable {
public:
- /// Supported archive types
- enum class IdCode : u32 {
- RomFS = 0x00000003,
- SaveData = 0x00000004,
- ExtSaveData = 0x00000006,
- SharedExtSaveData = 0x00000007,
- SystemSaveData = 0x00000008,
- SDMC = 0x00000009,
- SDMCWriteOnly = 0x0000000A,
- };
-
- Archive() { }
virtual ~Archive() { }
/**
* Get the IdCode of the archive (e.g. RomFS, SaveData, etc.)
* @return IdCode of the archive
*/
- virtual IdCode GetIdCode() const = 0;
+ virtual std::string GetName() const = 0;
/**
* Open a file specified by its path, using the specified mode
@@ -162,25 +162,12 @@ private:
virtual ~Archive() { }
/**
- * Get the IdCode of the archive (e.g. RomFS, SaveData, etc.)
- * @return IdCode of the archive
+ * Get a descriptive name for the archive (e.g. "RomFS", "SaveData", etc.)
*/